# Pad naar het bestand
$filePath = "C:\Windows\System32\IntegratedServicesRegionPolicySet.json"

# Controleer of het script als Administrator wordt uitgevoerd
if (-not ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole] "Administrator")) {
    Write-Host "Dit script moet als Administrator worden uitgevoerd." -ForegroundColor Red
    exit
}

# Controleer of het bestand bestaat
if (-not (Test-Path $filePath)) {
    Write-Host "Het bestand bestaat niet op $filePath" -ForegroundColor Red
    exit
}

# Stap 1: Overnemen van eigendom naar de groep Administrators
Write-Host "Eigendom wijzigen naar de groep Administrators..." -ForegroundColor Yellow
Start-Process -FilePath "takeown.exe" -ArgumentList "/F `"$filePath`" /A" -Wait -NoNewWindow

# Controleer of eigendom succesvol is gewijzigd
$owner = (Get-Acl $filePath).Owner
if ($owner -notlike "*Administrators") {
    Write-Host "Het wijzigen van eigendom naar Administrators is mislukt." -ForegroundColor Red
    exit
}
Write-Host "Eigendom succesvol gewijzigd naar $owner." -ForegroundColor Green

# Stap 2: Volledige controle geven aan de groep Administrators
Write-Host "Volledige toegang geven aan de groep Administrators..." -ForegroundColor Yellow
Start-Process -FilePath "icacls.exe" -ArgumentList "`"$filePath`" /grant:r Administrators:F /T /C" -Wait -NoNewWindow

# Controleer of de machtigingen correct zijn toegepast
$acl = Get-Acl $filePath
if ($acl.Access | Where-Object { $_.IdentityReference -like "*Administrators" -and $_.FileSystemRights -eq "FullControl" }) {
    Write-Host "De groep Administrators heeft nu volledige toegang." -ForegroundColor Green
} else {
    Write-Host "Toegang wijzigen is mislukt." -ForegroundColor Red
    exit
}

# Stap 3: JSON aanpassen
Write-Host "De JSON-inhoud aanpassen..." -ForegroundColor Yellow

# JSON inlezen
$jsonContent = Get-Content -Path $filePath -Raw | ConvertFrom-Json

# Wijzigen van de inhoud: Verwijder "NL" onder specifieke "guid"
foreach ($policy in $jsonContent.policies) {
    if ($policy.guid -eq "{1d290cdb-499c-4d42-938a-9b8dceffe998}") {
        $policy.conditions.region.disabled = $policy.conditions.region.disabled | Where-Object { $_ -ne "NL" }
        Write-Host "NL verwijderd uit 'disabled' lijst voor guid: $($policy.guid)." -ForegroundColor Green
    }
}

# Aangepaste JSON opslaan
$jsonContent | ConvertTo-Json -Depth 10 | Set-Content -Path $filePath -Force -Encoding UTF8

Write-Host "JSON-aanpassingen succesvol doorgevoerd en opgeslagen." -ForegroundColor Green
